==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgdumpbuffer.cpp <==
/***************************************************************************
                          dlgdumpbuffer.cpp  -  Dump Buffer dialog
                             -------------------
    begin                : Pi feb 28 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlgdumpbuffer.h"

#include <qcheckbox.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qwhatsthis.h>
#include <kfiledialog.h>
#include <klineedit.h>
#include <klocale.h>

dlgDumpBuffer::dlgDumpBuffer (QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Dump output buffer"), Ok|Cancel,
    Ok, true)
{
  //initial dialog size
  setInitialSize (QSize (300, 100));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QVBoxLayout *layout = new QVBoxLayout (page);

  setMainWidget (page);

  //where to start?
  chkcurpos = new QCheckBox (i18n ("&Start at current position"), page);
  QWhatsThis::add (chkcurpos, i18n ("When this is enabled, only the "
      "part of history buffer from currently displayed part up to the end of "
      "buffer will be dumped. Otherwise entire buffer will be dumped (default)."));

  //the file name
  QFrame *fileframe = new QFrame (page);
  QHBoxLayout *filelayout = new QHBoxLayout (fileframe);
  QLabel *lblname = new QLabel (i18n ("&File:"), fileframe);
  fname = new KLineEdit (fileframe);
  lblname->setBuddy (fname);
  QPushButton *filebutton = new QPushButton (i18n ("&Browse..."), fileframe);

  filelayout->setSpacing (5);
  filelayout->addWidget (lblname);
  filelayout->addWidget (fname);
  filelayout->addWidget (filebutton);

  //type
  QFrame *typeframe = new QFrame (page);
  QHBoxLayout *typelayout = new QHBoxLayout (typeframe);
  QLabel *lbltype = new QLabel (i18n ("&Dump format:"), typeframe);
  ttype = new QComboBox (typeframe);
  ttype->insertItem ("Plain text");
  ttype->insertItem ("Text with ANSI colors");
  ttype->insertItem ("HTML");
  lbltype->setBuddy (ttype);

  typelayout->setSpacing (5);
  typelayout->addWidget (lbltype);
  typelayout->addWidget (ttype);

  //connect the Browse button!
  connect (filebutton, SIGNAL (clicked ()), this, SLOT (browseFiles ()));

  layout->setSpacing (5);
  layout->addWidget (chkcurpos);
  layout->addWidget (fileframe);
  layout->addWidget (typeframe);

  //initial dialog settings...
  chkcurpos->setChecked (false);
  fname->setText (QDir::homeDirPath() + "/buffer_dump.txt");
}

dlgDumpBuffer::~dlgDumpBuffer ()
{

}

void dlgDumpBuffer::browseFiles ()
{
  fname->setText (KFileDialog::getSaveFileName ());
}

bool dlgDumpBuffer::curPos ()
{
  return chkcurpos->isChecked ();
}

QString dlgDumpBuffer::fileName ()
{
  return fname->text ();
}

void dlgDumpBuffer::setFileName (const QString &fName)
{
  fname->setText (fName);
}

int dlgDumpBuffer::type ()
{
  return ttype->currentItem() + 1;
}

void dlgDumpBuffer::setType (int t)
{
  ttype->setCurrentItem (t - 1);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgdumpbuffer.cpp <==
/***************************************************************************
                          dlgdumpbuffer.cpp  -  Dump Buffer dialog
                             -------------------
    begin                : Pi feb 28 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlgdumpbuffer.h"

#include <qcheckbox.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qwhatsthis.h>
#include <kfiledialog.h>
#include <klineedit.h>
#include <klocale.h>

dlgDumpBuffer::dlgDumpBuffer (QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Dump output buffer"), Ok|Cancel,
    Ok, true)
{
  //initial dialog size
  setInitialSize (QSize (300, 100));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QVBoxLayout *layout = new QVBoxLayout (page);

  setMainWidget (page);

  //where to start?
  chkcurpos = new QCheckBox (i18n ("&Start at current position"), page);
  QWhatsThis::add (chkcurpos, i18n ("When this is enabled, only the "
      "part of history buffer from currently displayed part up to the end of "
      "buffer will be dumped. Otherwise entire buffer will be dumped (default)."));

  //the file name
  QFrame *fileframe = new QFrame (page);
  QHBoxLayout *filelayout = new QHBoxLayout (fileframe);
  QLabel *lblname = new QLabel (i18n ("&File:"), fileframe);
  fname = new KLineEdit (fileframe);
  lblname->setBuddy (fname);
  QPushButton *filebutton = new QPushButton (i18n ("&Browse..."), fileframe);

  filelayout->setSpacing (5);
  filelayout->addWidget (lblname);
  filelayout->addWidget (fname);
  filelayout->addWidget (filebutton);

  //type
  QFrame *typeframe = new QFrame (page);
  QHBoxLayout *typelayout = new QHBoxLayout (typeframe);
  QLabel *lbltype = new QLabel (i18n ("&Dump format:"), typeframe);
  ttype = new QComboBox (typeframe);
  ttype->insertItem ("Plain text");
  ttype->insertItem ("Text with ANSI colors");
  ttype->insertItem ("HTML");
  lbltype->setBuddy (ttype);

  typelayout->setSpacing (5);
  typelayout->addWidget (lbltype);
  typelayout->addWidget (ttype);

  //connect the Browse button!
  connect (filebutton, SIGNAL (clicked ()), this, SLOT (browseFiles ()));

  layout->setSpacing (5);
  layout->addWidget (chkcurpos);
  layout->addWidget (fileframe);
  layout->addWidget (typeframe);

  //initial dialog settings...
  chkcurpos->setChecked (false);
  fname->setText (QDir::homeDirPath() + "/buffer_dump.txt");
}

dlgDumpBuffer::~dlgDumpBuffer ()
{

}

void dlgDumpBuffer::browseFiles ()
{
  fname->setText (KFileDialog::getSaveFileName ());
}

bool dlgDumpBuffer::curPos ()
{
  return chkcurpos->isChecked ();
}

QString dlgDumpBuffer::fileName ()
{
  return fname->text ();
}

void dlgDumpBuffer::setFileName (const QString &fName)
{
  fname->setText (fName);
}

int dlgDumpBuffer::type ()
{
  return ttype->currentItem() + 1;
}

void dlgDumpBuffer::setType (int t)
{
  ttype->setCurrentItem (t - 1);
}
